summaryrefslogtreecommitdiff
path: root/swift/common/request_helpers.py
diff options
context:
space:
mode:
authorSamuel Merritt <sam@swiftstack.com>2016-08-03 16:46:48 -0700
committerSamuel Merritt <sam@swiftstack.com>2016-08-03 16:46:48 -0700
commit425bb0d8b0f78feb362fac69cd75bfe8baa3f841 (patch)
tree904161d0d6de984e24c5039631d97078c60df2e0 /swift/common/request_helpers.py
parentd819ae00a5f589fc7cd11ddf95cfce7323d926e8 (diff)
downloadswift-425bb0d8b0f78feb362fac69cd75bfe8baa3f841.tar.gz
Fix stale docstring in SegmentedIterable.
At some point, we added stuff to listing_iter, but didn't update the docstring. I noticed this while trying to write code using a SegmentedIterable when it wouldn't take my 3-tuples like the docstring claimed it would. Change-Id: I8f6667e97b1277f5b403a5f6fa7f9d708bb19249
Diffstat (limited to 'swift/common/request_helpers.py')
-rw-r--r--swift/common/request_helpers.py14
1 files changed, 11 insertions, 3 deletions
diff --git a/swift/common/request_helpers.py b/swift/common/request_helpers.py
index 65f21bebc..9d231900c 100644
--- a/swift/common/request_helpers.py
+++ b/swift/common/request_helpers.py
@@ -304,10 +304,18 @@ class SegmentedIterable(object):
:param req: original request object
:param app: WSGI application from which segments will come
+
:param listing_iter: iterable yielding the object segments to fetch,
- along with the byte subranges to fetch, in the
- form of a tuple (object-path, first-byte, last-byte)
- or (object-path, None, None) to fetch the whole thing.
+ along with the byte subranges to fetch, in the form of a 5-tuple
+ (object-path, object-etag, object-size, first-byte, last-byte).
+
+ If object-etag is None, no MD5 verification will be done.
+
+ If object-size is None, no length verification will be done.
+
+ If first-byte and last-byte are None, then the entire object will be
+ fetched.
+
:param max_get_time: maximum permitted duration of a GET request (seconds)
:param logger: logger object
:param swift_source: value of swift.source in subrequest environ